pub struct Parse<'a> { /* private fields */ }Expand description
The Parse struct represents a message to parse a query string.
Available fields:
-
mtype: Identifies the message as a Parse command. (value ='P') -
mlen: Length of message contents in bytes, including self. -
statement: The name of the destination prepared statement. -
query: The query string to be parsed. -
param_types: OIDs of the parameter data types.
Implementations
Sourceimpl<'a> Parse<'a>
impl<'a> Parse<'a>
Sourcepub const fn is_buffer(buf: &'a [u8]) -> bool
pub const fn is_buffer(buf: &'a [u8]) -> bool
Checks the constant values for this struct to determine whether this message matches.
Sourcepub fn new(buf: &'a [u8]) -> Result<Self, ParseError>
pub fn new(buf: &'a [u8]) -> Result<Self, ParseError>
Creates a new instance of this struct from a given buffer.
Sourcepub fn param_types(&self) -> Array<'a, i16, i32>
pub fn param_types(&self) -> Array<'a, i16, i32>
OIDs of the parameter data types.
pub fn to_vec(self) -> Vec<u8> ⓘ